requiresAuthentication property
Flag to indicate that we need to add autharization headers to this request
Implementation
bool requiresAuthentication;
Flag to indicate that we need to add autharization headers to this request
bool requiresAuthentication;