copyWithDefaultSettings method
Returns copy of this object with changed default settings
Implementation
UIRoute<T> copyWithDefaultSettings(UIRouteSettings settings) {
return UIRoute<T>(name: name, child: child, defaultSettings: settings);
}
Returns copy of this object with changed default settings
UIRoute<T> copyWithDefaultSettings(UIRouteSettings settings) {
return UIRoute<T>(name: name, child: child, defaultSettings: settings);
}